@@ -1,13 +1,13 @@
 package Pg::CLI::psql;
 {
-  $Pg::CLI::psql::VERSION = '0.10';
+  $Pg::CLI::psql::VERSION = '0.11';
 }
 
 use Moose;
 
 use namespace::autoclean;
 
-use MooseX::Params::Validate qw( validated_hash validated_list );
+use MooseX::Params::Validate qw( validated_hash );
 use MooseX::SemiAffordanceAccessor;
 use MooseX::Types::Moose qw( ArrayRef Bool Defined Str );
 use MooseX::Types::Path::Class qw( File );
@@ -59,7 +59,7 @@ Pg::CLI::psql - Wrapper for the F<psql> utility
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
